/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * This scene is designed for 16:9 aspect ratio.                                                                   * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#version 3.7;

#local UseRadiosity = yes;

global_settings {
   assumed_gamma 2.2
   charset utf8
   max_trace_level 20
   #if (UseRadiosity)
      radiosity {
         pretrace_start .08
         pretrace_end .004
         count 600
         error_bound .002
         recursion_limit 2
         normal on
      } //radiosity
   #end //#if
} //global_settings

#include "colors.inc"
#include "BorderChars.inc"

#local CameraX = 0;
#local CameraY = 0;
#local CameraZ = 12.4;

camera {
   location <CameraX, CameraY, -CameraZ>
   direction <0, 0, 1>
   right (3840/2160) * x
   look_at <CameraX, CameraY, 0>
} //camera

#if (UseRadiosity)
   #local Dome = object {
      difference {
         sphere {0, 20001}
         sphere {0, 20000}
      } //difference
      texture {
         pigment {
            gradient z
            color_map {
               [0, 1 color White * 2.21 color White * .6]
            } //color_map
         } //pigment
         finish {emission 1 diffuse 0}
         scale <1, 1, 20000>
      } //texture
      no_reflection
   } //object
   object {Dome}
#else
   light_source {<60, 80, -200> color White * 1.65 shadowless}
#end //#if

#local TextColor_Outer = texture {pigment {color White}}

#local TextColor_Inner = texture {TextColor_Outer}

#local TextColor_Back = texture {pigment {color Black}}

#local BackgroundColor = texture {pigment {color <0.9000, 0.8659, 0.8153>}}

#macro CreateTexture_Gradient_Y (Color0, Color1)

   texture {
      pigment {
         gradient y
         color_map {
            [0 color Color0]
            [.4 color (Color0 * 75 + Color1 * 25) / 100]
            [.6 color (Color0 + Color1) / 2]
            [1 color Color1]
         } //color_map
      } //pigment
      finish {emission .1}
      #local YScaleAdd_Bottom = .75 / 2 * .95; //Height of the bottom of the "g"
      #local YScaleAdd_Top = .075; //Height of the top of the "*"
      scale <1, 1 + YScaleAdd_Bottom + YScaleAdd_Top, 1>
      translate -YScaleAdd_Bottom * y
   } //texture

#end //#macro CreateTexture_Gradient_Y

#macro CreateTexture_Gradient_X (Color0, Color1, Width)

   #local Color0_ = (Color0 + White * 2) / 3;
   #local Color1_ = (Color1 + White * 2) / 3;

   texture {
      pigment {
         gradient x
         color_map {
            [0 color Color0_]
            [1 color Color1_]
         } //color_map
      } //pigment
      finish {emission .1}
      scale <Width + .02, 1, 1>
      translate -.01 * x
   } //texture

#end //#macro CreateTexture_Gradient_Y

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * SET UP FONT STYLES                                                                                              * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#local FontVariationNumber = 0;
#local TextDepth = .08;
#local InvisibleBorderWidth0 = 0;
#local InvisibleBorderWidth1 = .06;
SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth0, -999, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
SetFontStyle (1, FontVariationNumber, TextDepth, InvisibleBorderWidth1, -999, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

#local FontVariationNumber = 2;
#local TextDepth = .08;
#local InvisibleBorderWidth = 0;
#local BorderWidth = .03;
#local BorderDepth = .05;

#local TextColor_Inner = CreateTexture_Gradient_Y (<0.9671, 0.6440, 0.6228>, <0.5376, 0.0436, 0.0674>) //Red
SetFontStyle (2, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, BorderDepth, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

#local TextColor_Inner = CreateTexture_Gradient_Y (<0.6280, 0.8939, 0.8723>, <0.1405, 0.4175, 0.1519>) //Green
SetFontStyle (3, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, BorderDepth, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

#local TextColor_Inner = CreateTexture_Gradient_Y (<0.5607, 0.6878, 0.9814>, <0.1811, 0.2305, 0.2083>); //Blue
SetFontStyle (4, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, BorderDepth, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

#local TextColor_Inner = CreateTexture_Gradient_Y (<0.9295, 0.9816, 0.7871>, <0.8464, 0.6731, 0.1741>) //Yellow
SetFontStyle (5, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, BorderDepth, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

#local TextColor_Inner = CreateTexture_Gradient_Y (<0.8196, 0.6339, 0.8780>, <0.0965, 0.1283, 0.3460>) //Purple
SetFontStyle (6, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, BorderDepth, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

#local TextColor_Inner = CreateTexture_Gradient_Y (<0.9461, 0.8010, 0.6769>, <0.8800, 0.3794, 0.0642>) //Orange
SetFontStyle (7, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, BorderDepth, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

#local NSteps = 9;
#local MinBorder = .03;
#local MaxBorder = .075; //Start with wide border and thin center
#local MinInvisibleBorder = 0;
#local MaxInvisibleBorder = .05; //End with thin stroke width
#local IndexCounter = 8;

#for (I, 0, NSteps - 1)
   #local CurBorder = MaxBorder - (MaxBorder - MinBorder) * (I / (NSteps - 1));
   SetFontStyle (IndexCounter, FontVariationNumber, TextDepth, MinInvisibleBorder, CurBorder, BorderDepth, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
   #local IndexCounter = IndexCounter + 1;
#end //#for

#for (I, 1, NSteps - 1)
   #local CurInvisibleBorder = MaxInvisibleBorder * (I / (NSteps - 1));
   SetFontStyle (IndexCounter, FontVariationNumber, TextDepth, CurInvisibleBorder, MinBorder, BorderDepth, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
   #local IndexCounter = IndexCounter + 1;
#end //#for

#local TextColor_Inner = CreateTexture_Gradient_Y (<0.9766, 0.6792, 0.9913>, <0.9645, 0.2563, 0.4112>) //Pink
SetFontStyle (25, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, BorderDepth, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

#local FontVariationNumber = 10;
#local TextDepth = .2;
#local EffectWidth = .04;
#local WallThickness = .02;
#local NSteps = 13;

MakeG1 (0) //Only necessary to get current character width for texture scaling purposes
#local TextColor_Outer = CreateTexture_Gradient_X (Red, Orange, CharacterWidth)
SetFontStyle (26, FontVariationNumber, TextDepth, EffectWidth, WallThickness, NSteps, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

MakeR2 (0)
#local TextColor_Outer = CreateTexture_Gradient_X (Orange, Yellow, CharacterWidth)
SetFontStyle (27, FontVariationNumber, TextDepth, EffectWidth, WallThickness, NSteps, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

MakeO2 (0)
#local TextColor_Outer = CreateTexture_Gradient_X (Yellow, Green, CharacterWidth)
SetFontStyle (28, FontVariationNumber, TextDepth, EffectWidth, WallThickness, NSteps, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

#local TextColor_Outer = CreateTexture_Gradient_X (Green, Blue, CharacterWidth)
SetFontStyle (29, FontVariationNumber, TextDepth, EffectWidth, WallThickness, NSteps, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

MakeV2 (0)
#local TextColor_Outer = CreateTexture_Gradient_X (Blue, DarkOrchid, CharacterWidth)
SetFontStyle (30, FontVariationNumber, TextDepth, EffectWidth, WallThickness, NSteps, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

MakeY2 (0)
#local TextColor_Outer = CreateTexture_Gradient_X (DarkOrchid, Red, CharacterWidth)
SetFontStyle (31, FontVariationNumber, TextDepth, EffectWidth, WallThickness, NSteps, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * THE SCENE                                                                                                       * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#local TextScale = 1;
#local UseActualParagraphHeight = no;

#local LeftMargin = -CameraZ / 1.125 + .6;
#local TopMargin = CameraZ / 2 - .4;
#local ZOffset = -.1;

#declare GAP_Width = .06;  //Distance between characters
#declare SPACE_Width = .2; //Distance between words
#declare LineSpacing = .5; //Distance between lines

#declare LineAlignment = LEFT; //Choices are LEFT, RIGHT, CENTERED, or JUSTIFIED
#declare MicroJustificationMethod = UNLIMITED; //Choices are LIMITED, UNLIMITED, or SCALED
#declare SPACE_ExpansionRate = 1.5; //Values > 1 will cause SPACE_Width to increase faster than GAP_Width
#declare AdditionalGAP_WidthPercentage = 60; //Only meaningful when LineAlignment = JUSTIFIED
#declare JustifyLastLinePercentage = 95; //Only meaningful when LineAlignment = JUSTIFIED

#local NLines = 1;

InitializeVariables (NLines)

//Use   \"   for quote marks.
//Use   ^    for a heart.

#declare LineText [0] = "{0}Normal {1}Thin {0}<Italic> {26}G{27}r{28}o{29}o{30}v{31}y";

CreateParagraph (NLines, TextScale, UseActualParagraphHeight)

#local Message1 = object {Paragraph translate <LeftMargin, TopMargin, ZOffset>}

//Next...

#local LeftMargin = -CameraZ / 1.125 + .6;
#local TopMargin = TopMargin - ParagraphHeight - LineSpacing;

#declare LineAlignment = LEFT; //Choices are LEFT, RIGHT, CENTERED, or JUSTIFIED
#declare MicroJustificationMethod = UNLIMITED; //Choices are LIMITED, UNLIMITED, or SCALED
#declare SPACE_ExpansionRate = 1.5; //Values > 1 will cause SPACE_Width to increase faster than GAP_Width
#declare AdditionalGAP_WidthPercentage = 60; //Only meaningful when LineAlignment = JUSTIFIED
#declare JustifyLastLinePercentage = 95; //Only meaningful when LineAlignment = JUSTIFIED

#local NLines = 2;

InitializeVariables (NLines)

#declare LineText [0] = "{2}Left";
#declare LineText [1] = "Alignment";

CreateParagraph (NLines, TextScale, UseActualParagraphHeight)

#local Message2 = object {Paragraph translate <LeftMargin, TopMargin, ZOffset>}

//Next...

#declare LineAlignment = CENTERED; //Choices are LEFT, RIGHT, CENTERED, or JUSTIFIED
#declare MicroJustificationMethod = UNLIMITED; //Choices are LIMITED, UNLIMITED, or SCALED
#declare SPACE_ExpansionRate = 1.5; //Values > 1 will cause SPACE_Width to increase faster than GAP_Width
#declare AdditionalGAP_WidthPercentage = 60; //Only meaningful when LineAlignment = JUSTIFIED
#declare JustifyLastLinePercentage = 95; //Only meaningful when LineAlignment = JUSTIFIED

#local NLines = 2;

InitializeVariables (NLines)

#declare LineText [0] = "{3}Center";
#declare LineText [1] = "Alignment";

CreateParagraph (NLines, TextScale, UseActualParagraphHeight)

#local LeftMargin = -ParagraphWidth / 2;

#local Message3 = object {Paragraph translate <LeftMargin, TopMargin, ZOffset>}

//Next...

#declare LineAlignment = RIGHT; //Choices are LEFT, RIGHT, CENTERED, or JUSTIFIED
#declare MicroJustificationMethod = UNLIMITED; //Choices are LIMITED, UNLIMITED, or SCALED
#declare SPACE_ExpansionRate = 1.5; //Values > 1 will cause SPACE_Width to increase faster than GAP_Width
#declare AdditionalGAP_WidthPercentage = 60; //Only meaningful when LineAlignment = JUSTIFIED
#declare JustifyLastLinePercentage = 95; //Only meaningful when LineAlignment = JUSTIFIED

#local NLines = 2;

InitializeVariables (NLines)

#declare LineText [0] = "{4}Right";
#declare LineText [1] = "Alignment";

CreateParagraph (NLines, TextScale, UseActualParagraphHeight)

#local LeftMargin = CameraZ / 1.125 - ParagraphWidth - .6;

#local Message4 = object {Paragraph translate <LeftMargin, TopMargin, ZOffset>}

//Next...

#local LeftMargin = -CameraZ / 1.125 + .6;
#local TopMargin = TopMargin - ParagraphHeight - LineSpacing;
#local TopMargin_Save = TopMargin;

#declare LineAlignment = JUSTIFIED; //Choices are LEFT, RIGHT, CENTERED, or JUSTIFIED
#declare MicroJustificationMethod = UNLIMITED; //Choices are LIMITED, UNLIMITED, or SCALED
#declare SPACE_ExpansionRate = 2; //Values > 1 will cause SPACE_Width to increase faster than GAP_Width
#declare AdditionalGAP_WidthPercentage = 60; //Only meaningful when LineAlignment = JUSTIFIED
#declare JustifyLastLinePercentage = 0; //Only meaningful when LineAlignment = JUSTIFIED

#local NLines = 2;

InitializeVariables (NLines)

#declare LineText [0] = "{5}Adjustable micro-justification";
#declare LineText [1] = "that also works with <italics>";

CreateParagraph (NLines, TextScale, UseActualParagraphHeight)

#local Message5 = object {Paragraph translate <LeftMargin, TopMargin, ZOffset>}

//Next...

#local LeftMargin = -CameraZ / 1.125 + .6;
#local TopMargin = TopMargin - ParagraphHeight - LineSpacing;

#declare LineAlignment = LEFT; //Choices are LEFT, RIGHT, CENTERED, or JUSTIFIED
#declare MicroJustificationMethod = UNLIMITED; //Choices are LIMITED, UNLIMITED, or SCALED
#declare SPACE_ExpansionRate = 1.5; //Values > 1 will cause SPACE_Width to increase faster than GAP_Width
#declare AdditionalGAP_WidthPercentage = 60; //Only meaningful when LineAlignment = JUSTIFIED
#declare JustifyLastLinePercentage = 95; //Only meaningful when LineAlignment = JUSTIFIED

#local NLines = 1;

InitializeVariables (NLines)

#declare LineText [0] = "{6}Automatic kerning";

CreateParagraph (NLines, TextScale, UseActualParagraphHeight)

#local Message6 = object {Paragraph translate <LeftMargin, TopMargin, ZOffset>}

//Next...

#local LeftMargin = -CameraZ / 1.125 + .6;
#local TopMargin = TopMargin - ParagraphHeight - LineSpacing;

#declare LineAlignment = LEFT; //Choices are LEFT, RIGHT, CENTERED, or JUSTIFIED
#declare MicroJustificationMethod = UNLIMITED; //Choices are LIMITED, UNLIMITED, or SCALED
#declare SPACE_ExpansionRate = 1.5; //Values > 1 will cause SPACE_Width to increase faster than GAP_Width
#declare AdditionalGAP_WidthPercentage = 60; //Only meaningful when LineAlignment = JUSTIFIED
#declare JustifyLastLinePercentage = 95; //Only meaningful when LineAlignment = JUSTIFIED

#local NLines = 1;

InitializeVariables (NLines)

#declare LineText [0] = "{7}Adjustable border/stroke widths:";

CreateParagraph (NLines, TextScale, UseActualParagraphHeight)

#local Message7 = object {Paragraph translate <LeftMargin, TopMargin, ZOffset>}

//Next...

#local LeftMargin = -CameraZ / 1.125 + .6;
#local TopMargin = TopMargin - ParagraphHeight - LineSpacing;

#declare LineAlignment = LEFT; //Choices are LEFT, RIGHT, CENTERED, or JUSTIFIED
#declare MicroJustificationMethod = UNLIMITED; //Choices are LIMITED, UNLIMITED, or SCALED
#declare SPACE_ExpansionRate = 1.5; //Values > 1 will cause SPACE_Width to increase faster than GAP_Width
#declare AdditionalGAP_WidthPercentage = 60; //Only meaningful when LineAlignment = JUSTIFIED
#declare JustifyLastLinePercentage = 95; //Only meaningful when LineAlignment = JUSTIFIED

#local NLines = 1;

InitializeVariables (NLines)

#declare LineText [0] = "{8}O{9}O{10}O{11}O{12}O{13}O{14}O{15}O{16}O{17}O{18}O{19}O{20}O{21}O{22}O{23}O{24}O";

CreateParagraph (NLines, TextScale, UseActualParagraphHeight)

#local Message8 = object {Paragraph translate <LeftMargin, TopMargin, ZOffset>}

//Next...

#declare LineSpacing = 0; //Distance between lines

#declare LineAlignment = JUSTIFIED; //Choices are LEFT, RIGHT, CENTERED, or JUSTIFIED
#declare MicroJustificationMethod = SCALED; //Choices are LIMITED, UNLIMITED, or SCALED
#declare SPACE_ExpansionRate = 1.5; //Values > 1 will cause SPACE_Width to increase faster than GAP_Width
#declare AdditionalGAP_WidthPercentage = 60; //Only meaningful when LineAlignment = JUSTIFIED
#declare JustifyLastLinePercentage = 95; //Only meaningful when LineAlignment = JUSTIFIED

#local TextScale = 1;
#local UseActualParagraphHeight = no;

#local NLines = 3;

InitializeVariables (NLines)

#declare LineText [0] = "{25}I LOVE";
#declare LineText [1] = "POV-";
#declare LineText [2] = "RAY";

CreateParagraph (NLines, TextScale, UseActualParagraphHeight)

#declare LineSpacing = .5; //Distance between lines

#local ParagraphHeight_Desired = 4; //3 * Height_Upper * TextScale + 2 * LineSpacing; Refering to the paragraph to match
#local TextScale = (ParagraphHeight_Desired - LineSpacing * (NLines - 1)) / ParagraphHeight;

CreateParagraph (NLines, TextScale, UseActualParagraphHeight)

#local LeftMargin = CameraZ / 1.125 - ParagraphWidth - .6;
#local TopMargin = TopMargin_Save;

#local Message9 = object {Paragraph translate <LeftMargin, TopMargin, ZOffset>}

object {Message1}
object {Message2}
object {Message3}
object {Message4}
object {Message5}
object {Message6}
object {Message7}
object {Message8}
object {Message9}

#local Background = object {
   plane {
      z, 0 inverse
      texture {BackgroundColor}
   } //plane
} //object

object {Background}
